@@ -1,20 +1,8 @@
 /*
-  This file is part of the KDE libraries
-  Copyright (c) 1999 Waldo Bastian <bastian@kde.org>
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef QT_NO_CAST_FROM_ASCII
@@ -25,6 +13,7 @@
 #include "klauncher_cmds.h"
 #include "klauncher_adaptor.h"
 #include "kslavelauncheradaptor.h"
+#include <klauncher_debug.h>
 
 #include <stdio.h>
 #include <qplatformdefs.h>
@@ -47,18 +36,19 @@
 #include <QUrl>
 #include <qplatformdefs.h>
 
-#include <kconfig.h>
+#include <KConfig>
 #include <QDebug>
-#include <klocalizedstring.h>
-#include <kdesktopfile.h>
-#include <kpluginloader.h> // to find kioslave modules
-#include <kprotocolmanager.h>
-#include <kprotocolinfo.h>
-#include <krun.h> // TODO port away from kiofilewidgets
+#include <KLocalizedString>
+#include <KDesktopFile>
+#include <KPluginLoader> // to find kioslave modules
+#include <KProtocolManager>
+#include <KProtocolInfo>
+#include <KRun> // TODO port away from kiofilewidgets
 
 #include <kio/desktopexecparser.h>
 #include <kio/global.h>
 #include <kio/slaveinterface.h>
+#include <kiogui_export.h>
 
 #ifdef Q_OS_WIN
 #include <qt_windows.h>
@@ -69,12 +59,6 @@
 // Dispose slaves after being idle for SLAVE_MAX_IDLE seconds
 #define SLAVE_MAX_IDLE  30
 
-#include <QLoggingCategory>
-Q_DECLARE_LOGGING_CATEGORY(KLAUNCHER)
-
-// logging category for this framework, default: log stuff >= warning
-Q_LOGGING_CATEGORY(KLAUNCHER, "kf5.kinit.klauncher", QtWarningMsg)
-
 static const char *const s_DBusStartupTypeToString[] =
 { "DBusNone", "DBusUnique", "DBusMulti", "ERROR" };
 
@@ -93,7 +77,7 @@ ssize_t kde_safe_write(int fd, const void *buf, size_t count)
     ssize_t ret = 0;
     K_EINTR_LOOP(ret, QT_WRITE(fd, buf, count));
     if (ret < 0) {
-        qWarning() << "write failed:" << strerror(errno);
+        qCWarning(KLAUNCHER) << "write failed:" << strerror(errno);
     }
     return ret;
 }
@@ -125,7 +109,7 @@ KLauncher::KLauncher()
     connect(&mConnectionServer, SIGNAL(newConnection()), SLOT(acceptSlave()));
     if (!mConnectionServer.isListening()) {
         // Severe error!
-        qWarning("KLauncher: Fatal error, can't create tempfile!");
+        qCWarning(KLAUNCHER, "KLauncher: Fatal error, can't create tempfile!");
         ::_exit(1);
     }
 
@@ -143,19 +127,19 @@ KLauncher::KLauncher()
     mSlaveDebug = QString::fromLocal8Bit(qgetenv("KDE_SLAVE_DEBUG_WAIT"));
     if (!mSlaveDebug.isEmpty()) {
 #ifndef USE_KPROCESS_FOR_KIOSLAVES
-        qWarning("Klauncher running in slave-debug mode for slaves of protocol '%s'", qPrintable(mSlaveDebug));
+        qCWarning(KLAUNCHER, "Klauncher running in slave-debug mode for slaves of protocol '%s'", qPrintable(mSlaveDebug));
 #else
         // Slave debug mode causes kdeinit to suspend the process waiting
         // for the developer to attach gdb to the process; we do not have
         // a good way of doing a similar thing if we are using QProcess.
         mSlaveDebug.clear();
-        qWarning("slave-debug mode is not available as Klauncher is not using kdeinit");
+        qCWarning(KLAUNCHER, "slave-debug mode is not available as Klauncher is not using kdeinit");
 #endif
     }
     mSlaveValgrind = QString::fromLocal8Bit(qgetenv("KDE_SLAVE_VALGRIND"));
     if (!mSlaveValgrind.isEmpty()) {
         mSlaveValgrindSkin = QString::fromLocal8Bit(qgetenv("KDE_SLAVE_VALGRIND_SKIN"));
-        qWarning("Klauncher running slaves through valgrind for slaves of protocol '%s'", qPrintable(mSlaveValgrind));
+        qCWarning(KLAUNCHER, "Klauncher running slaves through valgrind for slaves of protocol '%s'", qPrintable(mSlaveValgrind));
     }
 #ifdef USE_KPROCESS_FOR_KIOSLAVES
     qCDebug(KLAUNCHER) << "LAUNCHER_OK";
@@ -314,7 +298,7 @@ void KLauncher::processRequestReturn(int status, const QByteArray &requestData)
         return;
     }
 
-    qWarning() << "Unexpected request return" << (unsigned int) status;
+    qCWarning(KLAUNCHER) << "Unexpected request return" << (unsigned int) status;
 }
 
 void
@@ -757,6 +741,13 @@ KLauncher::start_service(KService::Ptr service, const QStringList &_urls,
     return true;
 }
 
+
+namespace KIOGuiPrivate {
+// defined in kprocessrunner.cpp
+extern bool KIOGUI_EXPORT checkStartupNotify(const KService *service, bool *silent_arg,
+                                             QByteArray *wmclass_arg);
+}
+
 void
 KLauncher::send_service_startup_info(KLaunchRequest *request, KService::Ptr service, const QByteArray &startup_id,
                                      const QStringList &envs)
@@ -771,7 +762,8 @@ KLauncher::send_service_startup_info(KLaunchRequest *request, KService::Ptr serv
     }
     bool silent;
     QByteArray wmclass;
-    if (!KRun::checkStartupNotify(QString(), service.data(), &silent, &wmclass)) {
+
+    if (!KIOGuiPrivate::checkStartupNotify(service.data(), &silent, &wmclass)) {
         return;
     }
     KStartupInfoId id;
